@@ -196,6 +196,7 @@ var_name_ds_sep = {
 
 # === metadata templates ===
 _ref_ds_attr = 'val_ref'  # global meta values variable that links to the reference dc
+_scale_ref_ds = 'val_scaling_ref'  # global meta values variable that links to the scaling reference dc
 _ds_short_name_attr = 'val_dc_dataset{:d}'  # attribute convention for other datasets
 _ds_pretty_name_attr = 'val_dc_dataset_pretty_name{:d}'  # attribute convention for other datasets
 _version_short_name_attr = 'val_dc_version{:d}'  # attribute convention for other datasets
@@ -521,6 +522,9 @@ def get_resolution_info(dataset, raise_error=False):
 # =====================================================
 # information needed for plotting the metadata-boxplots
 
+# Min number of samples per bin to create a boxplot:
+meta_boxplot_min_samples = 5
+
 lc_classes = {
     "unknown": "Not provided",
     0: 'Other',
@@ -640,4 +644,5 @@ _metadata_exclude = [
     'p_rho',
     'tau',
     'p_tau',
+    'status',
 ]
