@@ -4,6 +4,7 @@ import warnings
 from qa4sm_reader import globals
 from parse import *
 import warnings as warn
+import re
 
 
 class MixinVarmeta:
@@ -42,7 +43,7 @@ class MixinVarmeta:
         else:
             return self.ref_ds[0]
 
-    def get_varmeta(self) -> (tuple, tuple, tuple):
+    def get_varmeta(self) -> (tuple, tuple, tuple, tuple):
         """
         Get the datasets from the current variable. Each dataset is provided with shape
         (id, dict{names})
@@ -55,12 +56,27 @@ class MixinVarmeta:
             this is the dataset for which the metric is calculated
         dss : id, dict
             this is the additional dataset in TC variables
+        scale_ds: id, dict
+            this is the scaling dataset
         """
         if self.g == 0:
             ref_ds = self.Datasets.dataset_metadata(self.Datasets._ref_id())
-            mds, dss = None, None
+            mds, dss, scale_ds = None, None, None
 
         else:
+            scale_ds = None
+            if globals._scale_ref_ds in self.Datasets.meta.keys():
+                try:
+                    scale_ref_id = int(
+                        re.findall(
+                            r'\d+',
+                            self.Datasets.meta[globals._scale_ref_ds])[-1])
+                    scale_ds = self.Datasets.dataset_metadata(scale_ref_id)
+                except IndexError:
+                    warnings.warn(
+                        f"ID of scaling reference dataset could not be parsed, "
+                        f"units of spatial reference are used.")
+
             ref_ds = self.Datasets.dataset_metadata(self.parts['ref_id'])
             mds = self.Datasets.dataset_metadata(self.parts['sat_id0'])
             dss = None
@@ -81,7 +97,7 @@ class MixinVarmeta:
                     self.Datasets.dataset_metadata(self.parts['sat_id1'])
                 ]
 
-        return ref_ds, mds, dss
+        return ref_ds, mds, dss, scale_ds
 
 
 class QA4SMDatasets():
@@ -444,7 +460,7 @@ class MetricVariable(QA4SMVariable, MixinVarmeta):
         super().__init__(varname, global_attrs, values)
 
         self.Metric = QA4SMMetric(self.metric)
-        self.ref_ds, self.metric_ds, self.other_ds = self.get_varmeta()
+        self.ref_ds, self.metric_ds, self.other_ds, _ = self.get_varmeta()
 
 
 class ConfidenceInterval(QA4SMVariable, MixinVarmeta):
@@ -454,7 +470,7 @@ class ConfidenceInterval(QA4SMVariable, MixinVarmeta):
         super().__init__(varname, global_attrs, values)
 
         self.Metric = QA4SMMetric(self.metric)
-        self.ref_ds, self.metric_ds, self.other_ds = self.get_varmeta()
+        self.ref_ds, self.metric_ds, self.other_ds, _ = self.get_varmeta()
 
         self.bound = self.parts["bound"]
 
