@@ -104,7 +104,7 @@ class QA4SMPlotter:
         capt: str
             box caption
         """
-        ref_meta, mds_meta, other_meta = Var.get_varmeta()
+        ref_meta, mds_meta, other_meta, _ = Var.get_varmeta()
         ds_parts = []
         id, meta = mds_meta
         if tc:
@@ -140,22 +140,12 @@ class QA4SMPlotter:
         parts: list of parts for title
         """
         parts = []
-        ref, mds, other = [meta for meta in Var.get_varmeta()]
+        ref, mds, other, _ = Var.get_varmeta()
         if type == 'boxplot_basic':
             parts.append(ref[0])
             parts.extend([ref[1]['pretty_name'], ref[1]['pretty_version']])
 
-        elif type in ['barplot_basic_3ds', 'mapplot_basic_3ds']:
-            parts.append(ref[0])
-            parts.extend([ref[1]['pretty_name'], ref[1]['pretty_version']])
-            parts.append(mds[0])
-            parts.extend([mds[1]['pretty_name'], mds[1]['pretty_version']])
-            parts.append(other[0])
-            parts.extend([other[1]['pretty_name'], other[1]['pretty_version']])
-
-        elif type in [
-                'boxplot_tc', 'mapplot_basic', 'mapplot_tc', 'barplot_basic'
-        ]:
+        elif type in ['boxplot_tc', 'mapplot_basic', 'mapplot_tc']:
             parts.append(mds[0])
             parts.extend([mds[1]['pretty_name'], mds[1]['pretty_version']])
             parts.append(ref[0])
@@ -181,16 +171,12 @@ class QA4SMPlotter:
         titles = {
             'boxplot_basic':
             'Intercomparison of {} \nwith {}-{} ({}) as spatial reference\n ',
-            'barplot_basic':
-            '{} between {}-{} ({}) \nand {}-{}({}) as spatial reference\n ',
-            'barplot_basic_3ds':
-            '{} for {}-{} ({}) \nwith {}-{}({}) and \n{}-{}({})\n',
+            'barplot_basic': 'Validation Errors',
+            'mapplot_status': 'Validation Errors',
             'boxplot_tc':
             'Intercomparison of {} \nfor {}-{} ({}) \nwith {}-{} ({})\n ',
             'mapplot_basic':
             '{} for {}-{} ({}) with {}-{} ({}) as spatial reference',
-            'mapplot_basic_3ds':
-            '{} for {}-{} ({}) with {}-{}({}) \nand {}-{}({})\n',
             'mapplot_tc': '{} for {}-{} ({}) with {}-{} ({}) and {}-{} ({})',
             'metadata':
             'Intercomparison of {} by {}\nwith spatial reference: {}',
@@ -215,12 +201,11 @@ class QA4SMPlotter:
         # we stick to old naming convention
         names = {
             'boxplot_basic': 'boxplot_{}',
-            'barplot_basic': 'barplot_{}_{}-{}_and_{}-{}',
-            'barplot_basic_3ds': 'barplot_{}_{}-{}_and_{}-{}_and_{}-{}',
+            'barplot_basic': 'barplot_status',
+            'mapplot_status': 'overview_status',
             'mapplot_common': 'overview_{}',
             'boxplot_tc': 'boxplot_{}_for_{}-{}',
             'mapplot_double': 'overview_{}-{}_and_{}-{}_{}',
-            'mapplot_double_3ds': 'overview_{}-{}_and_{}-{}_and_{}-{}_{}',
             'mapplot_tc': 'overview_{}-{}_and_{}-{}_and_{}-{}_{}_for_{}-{}',
             'metadata': 'boxplot_{}_metadata_{}',
             'table': 'statistics_table',
@@ -261,28 +246,12 @@ class QA4SMPlotter:
             type of plot
         """
         name = self._filenames_lut(type=type)
-        ref_meta, mds_meta, other_meta = Var.get_varmeta()
+        ref_meta, mds_meta, other_meta, _ = Var.get_varmeta()
         # fetch parts of the name for the variable
-        if type in ["barplot_basic", "barplot_basic_3ds"]:
-            parts = [
-                Var.metric, ref_meta[0], ref_meta[1]['short_name'],
-                mds_meta[0], mds_meta[1]['short_name']
-            ]
-            if Var.g == 3:
-                parts = [
-                    Var.metric, ref_meta[0], ref_meta[1]['short_name'],
-                    mds_meta[0], mds_meta[1]['short_name'], other_meta[0],
-                    other_meta[1]['short_name']
-                ]
+        if type in ["barplot_basic", "mapplot_status"]:
+            parts = []
 
-        elif type == "mapplot_double_3ds":
-            parts = [
-                ref_meta[0], ref_meta[1]['short_name'], mds_meta[0],
-                mds_meta[1]['short_name'], other_meta[0],
-                other_meta[1]['short_name'], Var.metric
-            ]
-
-        elif type not in ["mapplot_tc", "mapplot_double", "barplot_basic"]:
+        elif type not in ["mapplot_tc", "mapplot_double"]:
             parts = [Var.metric]
             if mds_meta:
                 parts.extend([mds_meta[0], mds_meta[1]['short_name']])
@@ -392,9 +361,14 @@ class QA4SMPlotter:
             Specified in case mds meta is needed
         """
         # plot label
+        unit_ref = self.ref['short_name']
+
+        _, _, _, scl_meta = Var.get_varmeta()
+        if scl_meta:
+            unit_ref = scl_meta[1]['short_name']
         parts = [globals._metric_name[metric]]
         parts.append(globals._metric_description[metric].format(
-            globals.get_metric_units(self.ref['short_name'])))
+            globals.get_metric_units(unit_ref)))
         label = "{}{}".format(*parts)
         # generate plot
         figwidth = globals.boxplot_width * (len(df.columns) + 1)
@@ -452,7 +426,9 @@ class QA4SMPlotter:
         figwidth = globals.boxplot_width * (len(df.columns) + 1)
         # otherwise it's too narrow
         figsize = [figwidth, globals.boxplot_height]
-        fig, ax = plm.barplot(df=df, figsize=figsize, label=label)
+        fig, ax = plm.barplot(df=df,
+                              figsize=figsize,
+                              label='# of validation errors')
         if not Var:
             # when we only need reference dataset from variables (i.e. is the same):
             for Var in self.img._iter_vars(type="metric",
@@ -461,6 +437,7 @@ class QA4SMPlotter:
                 break
 
         title = self.create_title(Var, type=type)
+
         ax.set_title(title, pad=globals.title_pad)
 
         # add watermark
@@ -542,6 +519,7 @@ class QA4SMPlotter:
                                            df=values,
                                            type='boxplot_basic',
                                            ci=ci,
+                                           Var=Var,
                                            **plotting_kwargs)
         if not out_name:
             out_name = self.create_filename(Var, type='boxplot_basic')
@@ -657,26 +635,20 @@ class QA4SMPlotter:
         # we take the last iterated value for Var and use it for the file name
         for values, Var, _ in self._yield_values(metric=metric):
             # handle empty results
-
             if values.empty:
                 return None
 
-            ref_meta, mds_meta, other_meta = Var.get_varmeta()
+            if len(self.img.triple) and Var.g == 2:
+                continue
 
-            if other_meta:
-                self._barplot_definition(metric=metric,
-                                         df=values,
-                                         type='barplot_basic_3ds',
-                                         Var=Var)
-            else:
-                self._barplot_definition(metric=metric,
-                                         df=values,
-                                         type='barplot_basic',
-                                         Var=Var)
-            if other_meta:
-                out_name = self.create_filename(Var, type='barplot_basic_3ds')
-            else:
-                out_name = self.create_filename(Var, type='barplot_basic')
+            ref_meta, mds_meta, other_meta, _ = Var.get_varmeta()
+
+            self._barplot_definition(metric=metric,
+                                     df=values,
+                                     type='barplot_basic',
+                                     Var=Var)
+
+            out_name = self.create_filename(Var, type='barplot_basic')
 
             # save or return plotting objects
             if save_files:
@@ -701,7 +673,7 @@ class QA4SMPlotter:
 
         Parameters
         ----------
-        Var : QA4SMMetricVariab;e
+        Var : QA4SMMetricVariable
             Var in the image to make the map for.
         out_name: str
             name of output file
@@ -723,7 +695,7 @@ class QA4SMPlotter:
         -------
         fnames: list of file names with all the extensions
         """
-        ref_meta, mds_meta, other_meta = Var.get_varmeta()
+        ref_meta, mds_meta, other_meta, scl_meta = Var.get_varmeta()
         metric = Var.metric
         ref_grid_stepsize = self.img.ref_dataset_grid_stepsize
         res, unit = self.img.res_info.values()
@@ -742,6 +714,11 @@ class QA4SMPlotter:
             elif not compute_dpi and unit == "km" and res <= 1:
                 style_kwargs["dpi"] = globals.dpi_max
 
+        # get the short_name of the scaling reference
+        scl_short = None
+        if scl_meta:
+            scl_short = scl_meta[1]['short_name']
+
         # create mapplot
         fig, ax = plm.mapplot(
             df=Var.values[Var.varname],
@@ -749,18 +726,19 @@ class QA4SMPlotter:
             ref_short=ref_meta[1]['short_name'],
             ref_grid_stepsize=ref_grid_stepsize,
             plot_extent=
-            None,  # if None, extent is sutomatically adjusted (as opposed to img.extent)
+            None,  # if None, extent is automatically adjusted (as opposed to img.extent)
+            scl_short=scl_short,
             **style_kwargs)
 
         # title and plot settings depend on the metric group
-        if Var.g == 0:
+        if Var.varname.startswith('status'):
+            title = self.create_title(Var=Var, type='mapplot_status')
+            save_name = self.create_filename(Var=Var, type="mapplot_status")
+        elif Var.g == 0:
             title = "{} between all datasets".format(
                 globals._metric_name[metric])
             save_name = self.create_filename(Var, type='mapplot_common')
-        elif Var.g == 3 and Var.varname.startswith('status'):
-            title = self.create_title(Var=Var, type='mapplot_basic_3ds')
-            save_name = self.create_filename(Var, type='mapplot_double_3ds')
-        elif Var.g == 2 or Var.varname.startswith('status'):
+        elif Var.g == 2:
             title = self.create_title(Var=Var, type='mapplot_basic')
             save_name = self.create_filename(Var, type='mapplot_double')
         else:
@@ -814,6 +792,8 @@ class QA4SMPlotter:
         fnames = []
         for Var in self.img._iter_vars(type="metric",
                                        filter_parms={"metric": metric}):
+            if len(self.img.triple) and Var.g == 2 and metric == 'status':
+                continue
             if not (np.isnan(Var.values.to_numpy()).all() or Var.is_CI):
                 fns = self.mapplot_var(Var,
                                        out_name=None,
@@ -852,7 +832,7 @@ class QA4SMPlotter:
 
         if Metric.name == 'status':
             fnames_bplot = self.barplot(metric='status',
-                                        out_types='png',
+                                        out_types=out_types,
                                         save_files=save_all)
 
         elif Metric.g == 0 or Metric.g == 2:
@@ -896,6 +876,9 @@ class QA4SMPlotter:
         plot_type : str, default is 'catplot'
             one of 'catplot' or 'multiplot', defines the type of plots for the 'classes' and 'continuous'
             metadata types
+        plotting_kwargs:
+            Keyword arguments for the plotting function
+
 
         Returns
         -------
@@ -909,6 +892,8 @@ class QA4SMPlotter:
                                                     mean_ci=False):
             values.append(data)
 
+        if not values:
+            raise PlotterError(f"No valid values for {metric}")
         values = pd.concat(values, axis=1)
         # override values from metric
         if df is not None:
@@ -916,8 +901,13 @@ class QA4SMPlotter:
         # get meta and select only metric values with metadata available
         meta_values = self.img.metadata[metadata].values.dropna()
         values = values.reindex(index=meta_values.index)
+
+        unit_ref = self.ref['short_name']
+        _, _, _, scl_meta = Var.get_varmeta()
+        if scl_meta:
+            unit_ref = scl_meta[1]['short_name']
         mu = globals._metric_description[metric].format(
-            globals.get_metric_units(self.ref['short_name']))
+            globals.get_metric_units(unit_ref))
 
         out = plm.boxplot_metadata(df=values,
                                    metadata_values=meta_values,
@@ -936,6 +926,7 @@ class QA4SMPlotter:
         metric: str,
         metadata: str,
         metadata_discrete: str,
+        **plotting_kwargs,
     ):
         """
         Cross-boxplot between two given metadata types
@@ -960,21 +951,35 @@ class QA4SMPlotter:
                                               stats=False,
                                               mean_ci=False):
             values.append(df)
+        if not values:
+            raise PlotterError(f"No valid values for {metric}")
         values = pd.concat(values, axis=1)
 
         metric_name = globals._metric_name[metric]
+
+        unit_ref = self.ref['short_name']
+        _, _, _, scl_meta = Var.get_varmeta()
+        if scl_meta:
+            unit_ref = scl_meta[1]['short_name']
+
         metric_units = globals._metric_description[metric].format(
-            globals.get_metric_units(self.ref['short_name']))
+            globals.get_metric_units(unit_ref))
 
         Meta_cont = self.img.metadata[metadata]
         meta_values = Meta_cont.values.dropna()
 
         bin_funct = plm.bin_function_lut(globals.metadata[metadata][2])
-        binned_values = bin_funct(
-            df=values,
-            metadata_values=meta_values,
-            meta_key=metadata,
-        )
+        kwargs = dict()
+        if 'meta_boxplot_min_samples' in plotting_kwargs:
+            kwargs['min_size'] = plotting_kwargs['meta_boxplot_min_samples']
+
+        binned_values = bin_funct(df=values,
+                                  metadata_values=meta_values,
+                                  meta_key=metadata,
+                                  **kwargs)
+        if binned_values is None:
+            raise PlotterError(
+                f"Could not bin metadata {metadata} with function {bin_funct}")
         # dictionary with subset values
         values_subset = {
             a_bin: values.reindex(index=binned_values[a_bin].index)
@@ -983,13 +988,14 @@ class QA4SMPlotter:
         kwargs = {
             "metric": metric,
             "metadata": metadata_discrete,
-            "common_y": metric_name + metric_units
+            "common_y": metric_name + metric_units,
         }
+        plotting_kwargs.update(kwargs)
         n_datasets = len(self.img.datasets.others)
         fig, axes = plm.aggregate_subplots(to_plot=values_subset,
                                            funct=self.meta_single,
                                            n_bars=n_datasets,
-                                           **kwargs)
+                                           **plotting_kwargs)
 
         return fig, axes
 
@@ -1063,6 +1069,7 @@ class QA4SMPlotter:
         self,
         metric,
         out_types: str = 'png',
+        meta_boxplot_min_samples: int = 5,
     ):
         """
         Plots and saves three metadata boxplots per metric (defined in globals.py):
@@ -1075,8 +1082,10 @@ class QA4SMPlotter:
         ----------
         metric : str
             name of metric
-        out_types: str or list
+        out_types: str or list, optional
             extensions which the files should be saved in
+        meta_boxplot_min_samples: int, optional
+            minimum number of samples per bin required to plot a metadata boxplot
 
         Return
         ------
@@ -1090,19 +1099,25 @@ class QA4SMPlotter:
             return filenames
 
         for meta_type, meta_keys in globals.out_metadata_plots.items():
+            try:
+                # the presence of instrument_depth in the out file depends on the ismn release version
+                if all(meta_key in self.img.metadata.keys()
+                       for meta_key in meta_keys):
+                    outfiles = self.plot_metadata(
+                        metric,
+                        *meta_keys,
+                        save_file=True,
+                        out_types=out_types,
+                        meta_boxplot_min_samples=meta_boxplot_min_samples)
+                    filenames.extend(outfiles)
 
-            # the presence of instrument_depth in the out file depends on the ismn release version
-            if all(meta_key in self.img.metadata.keys()
-                   for meta_key in meta_keys):
-                outfiles = self.plot_metadata(metric,
-                                              *meta_keys,
-                                              save_file=True,
-                                              out_types=out_types)
-                filenames.extend(outfiles)
-
-            else:
-                warnings.warn("Not all: " + ", ".join(meta_keys) +
-                              " are present in the netCDF variables")
+                else:
+                    warnings.warn("Not all: " + ", ".join(meta_keys) +
+                                  " are present in the netCDF variables")
+            except PlotterError as e:
+                warnings.warn(
+                    f"Too few points are available to generate '{meta_type}` "
+                    f"metadata-based `{metric}` plots.")
 
         return filenames
 
