@@ -529,7 +529,8 @@ def _make_cbar(fig,
                ref_short: str,
                metric: str,
                label=None,
-               diff_map=False):
+               diff_map=False,
+               scl_short=None):
     """
     Make colorbar to use in plots
 
@@ -543,18 +544,26 @@ def _make_cbar(fig,
         from fig.add_subplot
     ref_short: str
         name of ref dataset
+    scl_short : str, default is None
+        name of scaling dataset
     metric: str
         name of metric
     label: str
         label to describe the colorbar
     diff_map : bool, default is False
         Whether the colorbar is for a difference plot
+
     """
     if label is None:
         label = globals._metric_name[metric] + \
                 globals._metric_description[metric].format(
                     globals.get_metric_units(ref_short)
                 )
+        if scl_short:
+            label = globals._metric_name[metric] + \
+                    globals._metric_description[metric].format(
+                        globals.get_metric_units(scl_short)
+                    )
 
     extend = get_extend_cbar(metric)
     if diff_map:
@@ -903,7 +912,8 @@ def bin_continuous(
     sorted = np.sort(meta_range)
     if len(meta_range) < min_size:
         raise ValueError(
-            "There are too few points per metadata to generate the boxplots. You can set 'min_size'"
+            "There are too few points per metadata to generate the boxplots. "
+            f"You can set 'min_size' (now at {min_size})"
             "to a lower value to allow for smaller samples.")
     bin_values, unique_values, bin_size = resize_bins(sorted, nbins)
     # adjust bins to have the specified number of bins if possible, otherwise enough valoues per bin
@@ -1334,6 +1344,7 @@ def boxplot_metadata(
     nbins=4,
     axis=None,
     plot_type: str = "catplot",
+    meta_boxplot_min_samples=5,
     **bplot_kwargs,
 ) -> tuple:
     """
@@ -1360,6 +1371,9 @@ def boxplot_metadata(
     plot_type : str, default is 'catplot'
         one of 'catplot' or 'multiplot', defines the type of plots for the 'classes' and 'continuous'
         metadata types
+    meta_boxplot_min_samples: int, optional (default: 5)
+        Minimum number of points in a bin to be plotted.
+        If not enough points are available, the plot is not created.
 
     Returns
     -------
@@ -1379,6 +1393,7 @@ def boxplot_metadata(
         metadata_values=metadata_values,
         meta_key=meta_key,
         nbins=nbins,
+        min_size=meta_boxplot_min_samples,
     )
     if to_plot is None:
         raise PlotterError(
@@ -1413,6 +1428,7 @@ def boxplot_metadata(
 def mapplot(df,
             metric,
             ref_short,
+            scl_short=None,
             ref_grid_stepsize=None,
             plot_extent=None,
             colormap=None,
@@ -1435,6 +1451,9 @@ def mapplot(df,
             name of the metric for the plot
         ref_short : str
                 short_name of the reference dataset (read from netCDF file)
+        scl_short : str, default is None
+            short_name of the scaling dataset (read from netCDF file).
+            None if no scaling method is selected in validation.
         ref_grid_stepsize : float or None, optional (None by default)
                 angular grid stepsize, needed only when ref_is_angular == False,
         plot_extent : tuple or None
@@ -1522,7 +1541,8 @@ def mapplot(df,
                 Patch(facecolor=cls[x], label=labs[x])
                 for x in range(len(globals.status)) if (x - 1) in vals
             ],
-                      loc='right')
+                      loc='lower center',
+                      ncol=4)
 
     else:  # mapplot
         if not plot_extent:
@@ -1548,7 +1568,8 @@ def mapplot(df,
                 Patch(facecolor=cls[x], label=labs[x])
                 for x in range(len(globals.status)) if (x - 1) in vals
             ],
-                      loc='right')
+                      loc='lower center',
+                      ncol=4)
 
     if add_cbar:  # colorbar
         _make_cbar(fig,
@@ -1557,7 +1578,8 @@ def mapplot(df,
                    ref_short,
                    metric,
                    label=label,
-                   diff_map=diff_map)
+                   diff_map=diff_map,
+                   scl_short=scl_short)
     style_map(ax, plot_extent, **style_kwargs)
 
     return fig, ax
