@@ -8,7 +8,6 @@ import shutil
 
 import qa4sm_reader.plot_all as pa
 
-
 # if sys.platform.startswith("win"):
 #     pytestmark = pytest.mark.skip(
 #         "Failing on Windows."
@@ -25,9 +24,8 @@ def plotdir():
 def test_plot_all(plotdir):
     """Plot all - including metadata based plots - to temporary directory and count files"""
     testfile = '0-ISMN.soil_moisture_with_1-C3S.sm.nc'
-    testfile_path = os.path.join(
-        os.path.dirname(__file__), '..', 'tests', 'test_data', 'metadata', testfile
-    )
+    testfile_path = os.path.join(os.path.dirname(__file__), '..', 'tests',
+                                 'test_data', 'metadata', testfile)
 
     pa.plot_all(
         filepath=testfile_path,
