@@ -56,6 +56,28 @@ def irrgrid_plotter(plotdir):
     return plotter
 
 
+@pytest.fixture
+def barplot_plotter(plotdir):
+    testfile = '0-ASCAT.sm_with_1-GLDAS.SoilMoi0_10cm_inst.nc'
+    testfile_path = os.path.join(os.path.dirname(__file__), '..', 'tests',
+                                 'test_data', 'basic', testfile)
+    img = QA4SMImg(testfile_path)
+    plotter = QA4SMPlotter(img, plotdir)
+
+    return plotter
+
+
+@pytest.fixture
+def ref_scaling_ds_plotter(plotdir):
+    testfile = '6-ISMN.soil moisture_with_1-C3S.sm_with_2-C3S.sm_with_3-SMOS.Soil_Moisture_with_4-SMAP.soil_moisture_with_5-ASCAT.sm.nc'
+    testfile_path = os.path.join(os.path.dirname(__file__), '..', 'tests',
+                                 'test_data', 'basic', testfile)
+    img = QA4SMImg(testfile_path)
+    plotter = QA4SMPlotter(img, plotdir)
+
+    return plotter
+
+
 @pytest.fixture
 def ref_dataset_grid_stepsize(irrgrid_plotter):
     ref_dataset_grid_stepsize = irrgrid_plotter.img.ref_dataset_grid_stepsize
@@ -97,17 +119,6 @@ def meta_plotter(plotdir):
     return plotter
 
 
-@pytest.fixture
-def barplot_plotter(plotdir):
-    testfile = '0-ASCAT.sm_with_1-GLDAS.SoilMoi0_10cm_inst.nc'
-    testfile_path = os.path.join(os.path.dirname(__file__), '..', 'tests',
-                                 'test_data', 'basic', testfile)
-    img = QA4SMImg(testfile_path)
-    plotter = QA4SMPlotter(img, plotdir)
-
-    return plotter
-
-
 def test_mapplot(basic_plotter, plotdir):
     n_obs_files = basic_plotter.mapplot_metric('n_obs',
                                                out_types='png',
@@ -364,6 +375,7 @@ def test_boxplot_basic_ci(tc_ci_plotter, plotdir):
     shutil.rmtree(plotdir)
 
 
+
 def test_boxplot_tc_ci(tc_ci_plotter, plotdir):
     snr_files = tc_ci_plotter.boxplot_tc('snr',
                                          out_types='svg',
@@ -374,6 +386,22 @@ def test_boxplot_tc_ci(tc_ci_plotter, plotdir):
     shutil.rmtree(plotdir)
 
 
+def test_scaling_reference_unit(ref_scaling_ds_plotter, plotdir):
+    img = ref_scaling_ds_plotter.img
+    g = img._iter_vars(filter_parms={'metric': 'RMSD'})
+    Var = next(g)
+    ref_meta, mds_meta, other_meta, scl_meta = Var.get_varmeta()
+    mds_unit = mds_meta[1]['mu']
+    ref_unit = ref_meta[1]['mu']
+    scl_unit = scl_meta[1]['mu']
+    assert mds_unit == 'm³/m³'
+    assert ref_unit == 'm³/m³'
+    assert scl_unit == '% saturation'
+
+    shutil.rmtree(plotdir)
+
+
+
 def test_bin_continuous():
     """Test continuous binning with 'elevation' metadata"""
     meta_val = pd.DataFrame(data=np.linspace(1, 100, 100),
